--- old/usr/src/lib/libipadm/common/ipadm_prop.c	2012-06-13 12:04:15.993388028 +0000
+++ new/usr/src/lib/libipadm/common/ipadm_prop.c	2012-06-13 12:04:19.081843425 +0000
@@ -26,7 +26,7 @@
  * This file contains routines that are used to modify/retrieve protocol or
  * interface property values. It also holds all the supported properties for
  * both IP interface and protocols in `ipadm_prop_desc_t'. Following protocols
- * are supported: IP, IPv4, IPv6, TCP, SCTP, UDP and ICMP.
+ * are supported: IP, IPv4, IPv6, TCP, SCTP, UDP, ICMP and DCCP.
  *
  * This file also contains walkers, which walks through the property table and
  * calls the callback function, of the form `ipadm_prop_wfunc_t' , for every
@@ -82,7 +82,7 @@
 /* array of protocols we support */
 static int protocols[] = { MOD_PROTO_IP, MOD_PROTO_RAWIP,
 			    MOD_PROTO_TCP, MOD_PROTO_UDP,
-			    MOD_PROTO_SCTP };
+			    MOD_PROTO_SCTP, MOD_PROTO_DCCP };
 
 /*
  * Supported IP protocol properties.
@@ -239,6 +239,30 @@
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
+/* Supported DCCP protocol properties */
+static ipadm_prop_desc_t ipadm_dccp_prop_table[] = {
+	{ "extra_priv_ports", IPADMPROP_CLASS_MODULE, MOD_PROTO_DCCP,
+	    IPADMPROP_MULVAL, i_ipadm_set_eprivport, i_ipadm_get_prop,
+	    i_ipadm_get_prop },
+
+	{ "largest_anon_port", IPADMPROP_CLASS_MODULE, MOD_PROTO_DCCP, 0,
+	    i_ipadm_set_prop, i_ipadm_get_prop, i_ipadm_get_prop },
+
+	{ "recv_maxbuf", IPADMPROP_CLASS_MODULE, MOD_PROTO_DCCP, 0,
+	    i_ipadm_set_prop, i_ipadm_get_prop, i_ipadm_get_prop },
+
+	{ "send_maxbuf", IPADMPROP_CLASS_MODULE, MOD_PROTO_DCCP, 0,
+	    i_ipadm_set_prop, i_ipadm_get_prop, i_ipadm_get_prop },
+
+	{ "smallest_anon_port", IPADMPROP_CLASS_MODULE, MOD_PROTO_DCCP, 0,
+	    i_ipadm_set_prop, i_ipadm_get_prop, i_ipadm_get_prop },
+
+	{ "smallest_nonpriv_port", IPADMPROP_CLASS_MODULE, MOD_PROTO_DCCP, 0,
+	    i_ipadm_set_prop, i_ipadm_get_prop, i_ipadm_get_prop },
+
+	{ NULL, 0, 0, 0, NULL, NULL, NULL }
+};
+
 /*
  * A dummy private property structure, used while handling private
  * protocol properties (properties not yet supported by libipadm).
@@ -266,6 +290,8 @@
 		return (ipadm_udp_prop_table);
 	case MOD_PROTO_SCTP:
 		return (ipadm_sctp_prop_table);
+	case MOD_PROTO_DCCP:
+		return (ipadm_dccp_prop_table);
 	}
 
 	return (NULL);
@@ -320,6 +346,8 @@
 		return ("udp");
 	case MOD_PROTO_SCTP:
 		return ("sctp");
+	case MOD_PROTO_DCCP:
+		return ("dccp");
 	}
 
 	return (NULL);
@@ -346,6 +374,8 @@
 		return (MOD_PROTO_SCTP);
 	else if (strcmp(protostr, "arp") == 0)
 		return (MOD_PROTO_IP);
+	else if (strcmp(protostr, "dccp") == 0)
+		return (MOD_PROTO_DCCP);
 
 	return (MOD_PROTO_NONE);
 }
